kiwi.storage.subformat Package
==============================

Subpackages
-----------

.. toctree::

    kiwi.storage.subformat.template

Submodules
----------

`kiwi.storage.subformat.base` Module
------------------------------------

.. automodule:: kiwi.storage.subformat.base
    :members:
    :undoc-members:
    :show-inheritance:

`kiwi.storage.subformat.gce` Module
-----------------------------------

.. automodule:: kiwi.storage.subformat.gce
    :members:
    :undoc-members:
    :show-inheritance:

`kiwi.storage.subformat.qcow2` Module
-------------------------------------

.. automodule:: kiwi.storage.subformat.qcow2
    :members:
    :undoc-members:
    :show-inheritance:

`kiwi.storage.subformat.vhd` Module
-----------------------------------

.. automodule:: kiwi.storage.subformat.vhd
    :members:
    :undoc-members:
    :show-inheritance:

`kiwi.storage.subformat.vhdfixed` Module
----------------------------------------

.. automodule:: kiwi.storage.subformat.vhdfixed
    :members:
    :undoc-members:
    :show-inheritance:

`kiwi.storage.subformat.vmdk` Module
------------------------------------

.. automodule:: kiwi.storage.subformat.vmdk
    :members:
    :undoc-members:
    :show-inheritance:


Module Contents
---------------

.. automodule:: kiwi.storage.subformat
    :members:
    :undoc-members:
    :show-inheritance:
